@@ -2,4 +2,4 @@ from easytorch.data import ETDataset, ETDataHandle, UnPaddedDDPSampler
 from easytorch.metrics import ETMetrics, ETAverages, Prf1a, ConfusionMatrix, ETMeter, AUCROCMetrics
 
 from .easytorch import EasyTorch
-from .trainer import ETTrainer
+from .runner import ETRunner
